import os

from flask_wtf import FlaskForm
from wtforms import StringField, SelectField
from wtforms.validators import InputRequired
import serial


class SerialForm(FlaskForm):
    port = SelectField('Port', validators=[InputRequired()],
                       choices=[(os.path.join('/dev', s), s)
                                for s in os.listdir('/dev')
                                if s.startswith('tty')])
    baud = SelectField('Baudrate', validators=[InputRequired()],
                       choices=(
                           ('9600', '9600'), ('14400', '14400'),
                           ('19200', '19200'), ('38400', '38400')
                       )
    )
    size = SelectField('Bytesize', validators=[InputRequired()],
                       choices=[('', '')] + [(getattr(serial, s), s)
                                             for s in dir(serial)
                                             if s.endswith('BITS')]
    )
    prty = SelectField('Parität', validators=[InputRequired()],
                         choices=list(serial.PARITY_NAMES.items()))
    stop = SelectField('Stopbits', validators=[InputRequired()],
                       choices=[(getattr(serial, s), s)
                                for s in dir(serial)
                                if s.startswith('STOPBITS')])

class InputForm(FlaskForm):
    send = StringField('Senden', validators=[InputRequired()])

